__title__ = "Fields"
__description__ = "Add or remove fields"
__long_description__ = """
<p>This plugin is used to manage the fields annotations visible from the main "variant view"
window.</p>

The fields are divided into 3 main categories:
<ul>
<li><b>variants:</b> fields annotations concerning only the variant
(chromosome, position, reference base, alternative base, etc.).</li>
<li><b>annotations:</b> fields annotations relative to a transcript. They are added by annotation tools such as snpeff (gene,
consequence of the variant, impact rating, etc.).</li>
<li><b>samples:</b> fields annotations relative to the samples (genotype)</li>
</ul>

<p>As the number of fields is large, it may be interesting to <em>use the 
search button</em> to quickly find those that are relevant in a study.</p>
"""
__author__ = "Sacha schutz"
__version__ = "1.0.0"
